==> haskell-edit-distance-0.2.2.1-118-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 edit-distance
version:              0.2.2.1
visibility:           public
id:                   edit-distance-0.2.2.1-2E33wyfnSmY8UfQBlywYKU
key:                  edit-distance-0.2.2.1-2E33wyfnSmY8UfQBlywYKU
license:              BSD-3-Clause
copyright:            (c) 2008-2013 Maximilian Bolinbroke
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://github.com/phadej/edit-distance
synopsis:
    Levenshtein and restricted Damerau-Levenshtein edit distances

description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.

category:             Algorithms
abi:                  df41e50ad7aec109b4af442c6c239c75
exposed:              True
exposed-modules:      Text.EditDistance
hidden-modules:
    Text.EditDistance.EditCosts Text.EditDistance.SquareSTUArray
    Text.EditDistance.STUArray Text.EditDistance.Bits
    Text.EditDistance.MonadUtilities Text.EditDistance.ArrayUtilities

import-dirs:          /usr/lib/ghc-9.0.1/site-local/edit-distance-0.2.2.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/edit-distance-0.2.2.1
hs-libraries:         HSedit-distance-0.2.2.1-2E33wyfnSmY8UfQBlywYKU
depends:
    array-0.5.4.0 base-4.15.0.0 containers-0.6.4.1
    random-1.2.1-LetExsLOa3nDkhT0M1R6w

haddock-interfaces:
    /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock

haddock-html:         /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edit-distance-0.2.2.1-119-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 edit-distance
version:              0.2.2.1
visibility:           public
id:                   edit-distance-0.2.2.1-AnYmXhyp73m5vNKig2YOae
key:                  edit-distance-0.2.2.1-AnYmXhyp73m5vNKig2YOae
license:              BSD-3-Clause
copyright:            (c) 2008-2013 Maximilian Bolinbroke
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://github.com/phadej/edit-distance
synopsis:
    Levenshtein and restricted Damerau-Levenshtein edit distances

description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.

category:             Algorithms
abi:                  6c3bb2768a4af751f8268893d6f2b17f
exposed:              True
exposed-modules:      Text.EditDistance
hidden-modules:
    Text.EditDistance.EditCosts Text.EditDistance.SquareSTUArray
    Text.EditDistance.STUArray Text.EditDistance.Bits
    Text.EditDistance.MonadUtilities Text.EditDistance.ArrayUtilities

import-dirs:          /usr/lib/ghc-9.0.1/site-local/edit-distance-0.2.2.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/edit-distance-0.2.2.1
hs-libraries:         HSedit-distance-0.2.2.1-AnYmXhyp73m5vNKig2YOae
depends:
    array-0.5.4.0 base-4.15.0.0 containers-0.6.4.1
    random-1.2.1-CJdGQfuMFBr50G0gL4deb3

haddock-interfaces:
    /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock

haddock-html:         /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
